/* Copyright 2010 ESRI
* 
* All rights reserved under the copyright laws of the United States
* and applicable international laws, treaties, and conventions.
* 
* You may freely redistribute and use this sample code, with or
* without modification, provided you include the original copyright
* notice and use restrictions.
* 
* See the use restrictions at http://help.arcgis.com/en/sdk/10.0/usageRestrictions.htm
* 
*/
package arcgissamples.trackinganalyst.ui;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.IOException;

import javax.swing.*;

import com.esri.arcgis.controls.IGlobeHookHelper;
import com.esri.arcgis.controls.IToolbarControl2;
import com.esri.arcgis.geodatabase.IFeatureClass;
import com.esri.arcgis.geodatabase.IWorkspaceFactory;
import com.esri.arcgis.globecore.esriGlobeLayerType;
import com.esri.arcgis.interop.AutomationException;
import com.esri.arcgis.system.ExtensionManager;
import com.esri.arcgis.system.IExtensionManagerAdmin;
import com.esri.arcgis.system.IPropertySet;
import com.esri.arcgis.system.PropertySet;
import com.esri.arcgis.system.UID;
import com.esri.arcgis.trackinganalyst.AMSWorkspace;
import com.esri.arcgis.trackinganalyst.AMSWorkspaceFactory;
import com.esri.arcgis.trackinganalyst.ITrackingEnvironment;
import com.esri.arcgis.trackinganalyst.TemporalFeatureLayer;
import com.esri.arcgis.trackinganalyst.TrackingEnvironment;

public class ServiceInfoListener implements ActionListener {
	AMSWorkspace amsWorkspace = null;
	IGlobeHookHelper globeHookHelper = null;
	String serviceName = null;
	private ServiceInfoDialog serviceInfoDialog = null;
	private JDialog progressDialog = null;
	boolean isConnected = false;

	public ServiceInfoListener(ServiceInfoDialog dlg, IGlobeHookHelper ghh, AMSWorkspace amsWS) {
		this.serviceInfoDialog = dlg;
		this.globeHookHelper = ghh;
		this.amsWorkspace = amsWS;
	}

	public void actionPerformed(ActionEvent e) {
		if (e.getActionCommand().equalsIgnoreCase("selectLayer")) {
			serviceName = (String) serviceInfoDialog.getServiceComboBox().getSelectedItem();
		}

		if (e.getActionCommand().equalsIgnoreCase("addLayer")) {
			serviceInfoDialog.setVisible(false);

			getProgressDialog().setVisible(true);
			try {
				// Create the temporal layer and add it to the display
				TemporalFeatureLayer temporalLayer = createTemporalLayer();

				if (temporalLayer != null) {
					globeHookHelper.getGlobe().addLayerType(temporalLayer, esriGlobeLayerType.esriGlobeLayerTypeFloating, false);
					getProgressDialog().setVisible(false);
				}
			} catch (Exception e1) {
				e1.printStackTrace();
			}
		}

		if (e.getActionCommand().equalsIgnoreCase("cancel")) {
			try {
				serviceName = null;
				amsWorkspace.disconnect();
				serviceInfoDialog.setVisible(false);
			} catch (Exception e1) {
				e1.printStackTrace();
			}
		}
	}

	/*
	 * Create a new temporal layer with default symbology
	 */
	private TemporalFeatureLayer createTemporalLayer() {
		TemporalFeatureLayer featureLayer = null;
		try {
			featureLayer = new TemporalFeatureLayer();
			IFeatureClass featureClass = amsWorkspace.openFeatureClass(serviceName);
			featureLayer.setFeatureClassByRef(featureClass);

			return featureLayer;
		} catch (Exception e) {
			JOptionPane.showMessageDialog(serviceInfoDialog, "Could not find Tracking Service. Please check if \""
				+ serviceName + "\" is correct.\n" + e.getMessage());
		}

		return null;
	}

	/*
	 * Creates a Dialog box with a Progress bar in it. @return
	 */
	private JDialog getProgressDialog() {
		if (progressDialog == null) {
			progressDialog = new JDialog();
			progressDialog.setTitle("Retrieving Layer from Tracking Server...");
			JProgressBar bar = new JProgressBar();
			bar.setBorderPainted(true);
			bar.setIndeterminate(true);
			progressDialog.setLocationRelativeTo(serviceInfoDialog);
			progressDialog.setLocation(serviceInfoDialog.getWidth() / 2, serviceInfoDialog.getHeight() / 2);
			progressDialog.add(bar, BorderLayout.PAGE_START);
			progressDialog.pack();
			progressDialog.setSize(325, 50);
		}

		return progressDialog;
	}
}
